@@ -18,7 +18,7 @@ test_that("Queries return the correct primitive types", {
   conn <- setup_live_connection()
 
   expect_error(dbGetQuery(conn, "select null unknown"),
-               'Unsupported column type',
+               '"unknown" column type',
                label='column of type "unknown"')
   expect_equal_data_frame(dbGetQuery(conn, "select true bool"),
                data_frame(bool = TRUE))
@@ -85,6 +85,7 @@ test_that("all data types work", {
     type_double=1.0,
     type_decimal='1.414',
     type_varchar='a',
+    type_char='a',
     type_varbinary=NA,
     type_json='{"a":1}',
     type_date=as.Date('2015-03-01'),
@@ -117,6 +118,7 @@ test_that("all data types work", {
         CAST(1.0 AS DOUBLE) AS type_double,
         DECIMAL '1.414' AS type_decimal,
         CAST('a' AS VARCHAR) AS type_varchar,
+        CAST('a' AS CHAR) AS type_char,
         CAST('a' AS VARBINARY) AS type_varbinary,
         JSON_PARSE('{\"a\": 1}') AS type_json,
         DATE '2015-03-01' AS type_date,
@@ -143,6 +145,7 @@ test_that("all data types work", {
     type_double=NA_real_,
     type_decimal=NA_character_,
     type_varchar=NA_character_,
+    type_char=NA_character_,
     type_varbinary=NA,
     type_json=NA_character_,
     type_date=as.Date(NA),
@@ -170,6 +173,7 @@ test_that("all data types work", {
         CAST(NULL AS DOUBLE) AS type_double,
         CAST(NULL AS DECIMAL) AS type_decimal,
         CAST(NULL AS VARCHAR) AS type_varchar,
+        CAST(NULL AS CHAR) AS type_char,
         CAST(NULL AS VARBINARY) AS type_varbinary,
         JSON_PARSE(NULL) AS type_json,
         CAST(NULL AS DATE) AS type_date,
